var lesson = {
	files: [
		{
			name: "main",
			content: "import { render } from \"solid-js/web\";\nimport { For, createSignal } from \"solid-js\";\n\nconst App = () => {\n  const [todos, setTodos] = createSignal([])\n  let input;\n  let todoId = 0;\n\n  const addTodo = (text) => {\n    setTodos([...todos(), { id: ++todoId, text, completed: false }]);\n  }\n  const toggleTodo = (id) => {\n    setTodos(todos().map((todo) => (\n      todo.id !== id ? todo : { ...todo, completed: !todo.completed }\n    )));\n  }\n\n  return (\n    <>\n      <div>\n        <input ref={input} />\n        <button\n          onClick={(e) => {\n            if (!input.value.trim()) return;\n            addTodo(input.value);\n            input.value = \"\";\n          }}\n        >\n          Add Todo\n        </button>\n      </div>\n      <For each={todos()}>\n        {(todo) => {\n          const { id, text } = todo;\n          console.log(`Creating ${text}`)\n          return <div>\n            <input\n              type=\"checkbox\"\n              checked={todo.completed}\n              onchange={[toggleTodo, id]}\n            />\n            <span\n              style={{ \"text-decoration\": todo.completed ? \"line-through\" : \"none\"}}\n            >{text}</span>\n          </div>\n        }}\n      </For>\n    </>\n  );\n};\n\nrender(App, document.getElementById(\"app\"));\n"
		}
	]
};
var solved = {
	files: [
		{
			name: "main",
			content: "import { render } from \"solid-js/web\";\nimport { For, createSignal } from \"solid-js\";\n\nconst App = () => {\n  const [todos, setTodos] = createSignal([])\n  let input;\n  let todoId = 0;\n\n  const addTodo = (text) => {\n    const [completed, setCompleted] = createSignal(false); \n    setTodos([...todos(), { id: ++todoId, text, completed, setCompleted }]);\n  }\n  const toggleTodo = (id) => {\n    const index = todos().findIndex((t) => t.id === id);\n    const todo = todos()[index];\n    if (todo) todo.setCompleted(!todo.completed())\n  }\n\n  return (\n    <>\n      <div>\n        <input ref={input} />\n        <button\n          onClick={(e) => {\n            if (!input.value.trim()) return;\n            addTodo(input.value);\n            input.value = \"\";\n          }}\n        >\n          Add Todo\n        </button>\n      </div>\n      <For each={todos()}>\n        {(todo) => {\n          const { id, text } = todo;\n          console.log(`Creating ${text}`)\n          return <div>\n            <input\n              type=\"checkbox\"\n              checked={todo.completed()}\n              onchange={[toggleTodo, id]}\n            />\n            <span\n              style={{ \"text-decoration\": todo.completed() ? \"line-through\" : \"none\"}}\n            >{text}</span>\n          </div>\n        }}\n      </For>\n    </>\n  );\n};\n\nrender(App, document.getElementById(\"app\"));\n"
		}
	]
};
var markdown = "Solid でリアクティビティが細かく設定されている理由の 1 つは、ネストした更新を独立して処理できることです。ユーザーのリストを持っていて、ある名前を更新すると、リスト自体には影響を与えずに DOM 内の 1 箇所だけを更新できます。このようなことができる UI フレームワーク（しかもリアクティブなもの）はほとんどありません。\n\nしかし、どのようにこれを実現するのでしょうか？　この例では、Signal の中に Todo のリストがあります。Todo を完了済みとしてマークするためには、Todo を複製して置き換える必要があります。これは多くのフレームワークが採用している方法ですが、リストの差分を再実行したり、`console.log` に示されているように DOM 要素を再作成したりするので無駄が多いです。\n\n```js\nconst toggleTodo = (id) => {\n  setTodos(\n    todos().map((todo) => (todo.id !== id ? todo : { ...todo, completed: !todo.completed })),\n  );\n};\n```\n\nその代わり、Solid のようなきめ細かいライブラリでは、次のようにネストした Signal でデータを初期化します:\n\n```js\nconst addTodo = (text) => {\n  const [completed, setCompleted] = createSignal(false);\n  setTodos([...todos(), { id: ++todoId, text, completed, setCompleted }]);\n};\n```\n\nこれで、`setCompleted` を呼び出すことで、追加の差分なしに名前を更新できるようになりました。これは、複雑さをビューではなく、データに移したからです。また、データがどのように変化するかを正確に把握しています。\n\n```js\nconst toggleTodo = (id) => {\n  const index = todos().findIndex((t) => t.id === id);\n  const todo = todos()[index];\n  if (todo) todo.setCompleted(!todo.completed())\n}\n```\n`todo.completed` の残りの参照を `todo.completed()` に変更すると、この例では Todo を切り替えたときではなく、作成時にのみ `console.log` を実行するようになります。\n\nもちろん、これには手動でのマッピングが必要で、以前はこれが唯一の選択肢でした。しかし今ではプロキシのおかげで、この作業のほとんどを手動で行なうことなく、バックグラウンドで実行できるようになりました。次のチュートリアルに進んで、その方法を確認してください。\n";
var stores_nested_reactivity = {
	lesson: lesson,
	solved: solved,
	markdown: markdown
};

export { stores_nested_reactivity as default, lesson, markdown, solved };
